@@ -21,4 +21,4 @@
 #
 ##############################################################################
 
-import health_icd10pcs
+from . import health_icd10pcs
